Aes class

Constructors

Aes()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

aesDecrypt(Uint8List data) → Uint8List
aesDecryptBlock(Uint8List data) → Uint8List
aesEncrypt(Uint8List data) → Uint8List
aesEncryptBlock(Uint8List data) → Uint8List
aesSetKeys(Uint8List key, [Uint8List? iv]) → void
aesSetMode(AesMode mode) → void
aesSetParams(Uint8List key, Uint8List iv, AesMode mode) → void
getIV() → Uint8List
getKey() → Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited