CodecAES class

Inheritance

Constructors

CodecAES({required Uint8List key, required Uint8List iv, required AesMode mode})

Properties

decoder → Converter<String, Object>
Returns the decoder of this, converting from T to S.
no setteroverride
encoder → Converter<Object, String>
Returns the encoder from S to T.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<String, Object>
Inverts this.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(String encoded) → Object
Decodes encoded data.
inherited
encode(Object input) → String
Encodes input.
inherited
fuse<R>(Codec<String, R> other) → Codec<Object, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited