PBKDF2 class

Constructors

PBKDF2({int blockLength = 128, int iterationCount = 2048, int desiredKeyLength = 64, dynamic digestAlgorithm})

Properties

blockLength → int
final
desiredKeyLength → int
final
digestAlgorithm → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
iterationCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saltPrefix → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process({required Uint8List data, dynamic passphrase = "", Uint8List? salt}) → Uint8List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited