Utxo class

Constructors

Utxo({required OutputPointer outputPointer, required int timelock, required bool utxoMature, required int value})
Utxo.fromJson(Map<String, dynamic> json)
factory
Utxo.fromRawJson(String str)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
outputPointer ↔ OutputPointer
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timelock ↔ int
getter/setter pair
utxoMature ↔ bool
getter/setter pair
value ↔ int
getter/setter pair

Methods

jsonMap({bool asHex = false}) → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInput() → Input
toRawJson({bool asHex = false}) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited