UtxoPool class

Constructors

UtxoPool()

Properties

hashCode → int
The hash code for this object.
no setterinherited
map ↔ Map<OutputPointer, Utxo>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
cover({required int amountNanoWit, required UtxoSelectionStrategy utxoStrategy}) → List<Utxo>
insert(Utxo utxo) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Utxo utxo) → void
selectUtxos({required List<ValueTransferOutput> outputs, required UtxoSelectionStrategy utxoStrategy}) → List<Utxo>
shuffleUtxos() → List<Utxo>
sortUtxos(UtxoSelectionStrategy utxoSelectionStrategy) → List<Utxo>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited