AddressDataRequestsSolved class

Constructors

AddressDataRequestsSolved({required String address, required List<DataRequestSolvedInfo> dataRequestsSolved})
AddressDataRequestsSolved.fromJson(Map<String, dynamic> json)
factory
AddressDataRequestsSolved.fromRawJson(String str)
factory

Properties

address → String
final
dataRequestsSolved → List<DataRequestSolvedInfo>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited