AddressDetails class

Constructors

AddressDetails({required String address, required int balance, required int eligibility, required int reputation, required int totalReputation})
AddressDetails.fromJson(Map<String, dynamic> json)
factory
AddressDetails.fromRawJson(String str)
factory

Properties

address → String
final
balance → int
final
eligibility → int
final
hashCode → int
The hash code for this object.
no setterinherited
reputation → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalReputation → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited