AddressInfo class

Constructors

AddressInfo({required int active, required String address, required int block, required int commit, required int dataRequest, required String label, required int mint, required int reveal, required int tally, required int valueTransfer})
AddressInfo.fromJson(Map<String, dynamic> json)
factory

Properties

active → int
final
address → String
final
block → int
final
commit → int
final
dataRequest → int
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
final
mint → int
final
reveal → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tally → int
final
valueTransfer → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited