AddressMintInfo class

Constructors

AddressMintInfo({required bool confirmed, required int epoch, required String hash, required String miner, required int outputValue, required int timestamp})
AddressMintInfo.fromJson(Map<String, dynamic> json)
factory
AddressMintInfo.fromRawJson(String str)
factory

Properties

confirmed → bool
final
epoch → int
final
hash → String
final
hashCode → int
The hash code for this object.
no setterinherited
miner → String
final
outputValue → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printDebug() → void
rawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited