AddressStake class

Constructors

AddressStake({required int epoch, required int timestamp, required String hash, required String direction, required String validator, required String withdrawer, required int input_value, required int stake_value, required bool confirmed})
AddressStake.fromJson(Map<String, dynamic> data)
factory

Properties

confirmed → bool
final
direction → String
final
epoch → int
final
hash → String
final
hashCode → int
The hash code for this object.
no setterinherited
input_value → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stake_value → int
final
timestamp → int
final
validator → String
final
withdrawer → String
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited