AddressUnstakes class

Constructors

AddressUnstakes({required List<AddressUnstake> unstakes})
AddressUnstakes.fromJson(List data)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unstakes ↔ List<AddressUnstake>
getter/setter pair

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited