AddressValueTransferInfo class

Constructors

AddressValueTransferInfo({required int epoch, required int timestamp, required String hash, required String direction, required List<String> inputAddresses, required List<String> outputAddresses, required int value, required int fee, required int weight, required int priority, required bool locked, required bool confirmed})
AddressValueTransferInfo.fromJson(Map<String, dynamic> json)
factory
AddressValueTransferInfo.fromRawJson(String str)
factory

Properties

confirmed → bool
final
direction → String
final
epoch → int
final
fee → int
final
hash → String
final
hashCode → int
The hash code for this object.
no setterinherited
inputAddresses → List<String>
final
locked → bool
final
outputAddresses → List<String>
final
priority → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
final
value → int
final
weight → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited