BlockDetails class

Constructors

BlockDetails({required String blockHash, required int epoch, required int timestamp, required int drWeight, required int vtWeight, required int blockWeight, required bool confirmed, required bool reverted, required MintInfo mintInfo})
BlockDetails.fromJson(Map<String, dynamic> json)
factory

Properties

blockHash → String
final
blockWeight → int
final
confirmed → bool
final
drWeight → int
final
epoch → int
final
hashCode → int
The hash code for this object.
no setterinherited
mintInfo → MintInfo
final
reverted → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
final
vtWeight → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited