BurnRate class

Constructors

BurnRate({required int reverted, required int lies})
BurnRate.fromJson(Map<String, dynamic> data)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lies → int
final
reverted → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited