DrComposition class

Constructors

DrComposition({required int total, required int httpGet, required int httpPost, required int rng})
DrComposition.fromJson(Map<String, dynamic> data)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpGet → int
final
httpPost → int
final
rng → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited