DrHistory class

Constructors

DrHistory({required int total, required int failure})
DrHistory.fromJson(Map<String, dynamic> data)
factory

Properties

failure → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited