DrLieRate class

Constructors

DrLieRate({required int witnessingActs, required int errors, required int noRevealLies, required int outOfConsensusLies})
DrLieRate.fromJson(Map<String, dynamic> data)
factory

Properties

errors → int
final
hashCode → int
The hash code for this object.
no setterinherited
noRevealLies → int
final
outOfConsensusLies → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
witnessingActs → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited