ExplorerClient class

Constructors

ExplorerClient({required String url, required ExplorerMode mode})

Properties

client → RetryHttpClient
final
hashCode → int
The hash code for this object.
no setterinherited
mode → ExplorerMode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
SSL → bool
final
url → String
final

Methods

address({required String value, required String tab, bool findAll = false, int page = 1, int pageSize = 1000}) → Future
api(String method, [Map<String, dynamic> params = const {}]) → Uri
blockchain({int? page, int? pageSize}) → Future<PaginatedRequest<Blockchain>>
epoch({required int epoch}) → Future<BlockDetails>
explorerVersion() → Future<String>
getAllResults(PaginatedRequest firstResult, String callName, Map<String, dynamic> params) → Future<List>
getMultiUtxoInfo({required List<String> addresses}) → Future<Map<String, List<Utxo>>>
getStats({required int startEpoch, required int stopEpoch, required StatisticsParams statisticsType}) → Future
getUtxoInfo({required String address}) → Future<List<Utxo>>
hash({required String value, bool simple = true, bool findAll = true}) → Future
Creates a combined hash code for a number of objects.
override
home() → Future<Home>
mempool({required String transactionType, int? startEpoch, int? stopEpoch}) → Future<List<Mempool>>
networkBalances({int? page, int? pageSize}) → Future<PaginatedRequest<NetworkBalances>>
nonce({required String validator, required String withdrawer}) → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protocolVersion([bool all = false]) → Future<Map<String, dynamic>>
reputation() → Future<NetworkReputation>
send({required Map<String, dynamic> transaction, bool test = false}) → Future
sendVTTransaction(VTTransaction transaction, {bool testing = true}) → Future
stakes({String? validator, String? withdrawer}) → Future<List<StakeRewardsInfo?>>
stakingPriority() → Future<PrioritiesEstimate>
statistics({required int startEpoch, required int stopEpoch, required StatisticsParams statisticsType}) → Future
status() → Future<Status>
supply({required SupplyParams transactionType}) → Future<String>
tapi() → Future<Tapi>
toString() → String
A string representation of this object.
inherited
transactionMempool({required MempoolTransactionType transactionType}) → Future<List>
valueTransferPriority() → Future<PrioritiesEstimate>

Operators

operator ==(Object other) → bool
The equality operator.
inherited