HashInfo class

Implementers

Constructors

HashInfo({required String txnHash, required TxStatusLabel status, required TransactionType type, required int txnTime, required dynamic blockHash})
HashInfo.fromJson(Map<String, dynamic> json)
factory
HashInfo.fromRawJson(String str)
factory

Properties

blockHash → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TxStatusLabel
final
txnHash → String
final
txnTime → int
final
type → TransactionType
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printDebug() → void
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited