Home class

Class Mappings to the Explorer API methods

Constructors

Home({required int lastUpdated, required List<List> latestBlocks, required List<List> latestDataRequests, required List<List> latestValueTransfers, required NetworkStats networkStats, required SupplyInfo supplyInfo})
Home.fromJson(Map<String, dynamic> json)
factory
Home.fromRawJson(String str)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastUpdated → int
final
latestBlocks → List<List>
final
latestDataRequests → List<List>
final
latestValueTransfers → List<List>
final
networkStats → NetworkStats
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supplyInfo → SupplyInfo
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited