Mempool class

Constructors

Mempool({required int timestamp, required List<int?> fee, required List<int?> amount})
Mempool.fromJson(dynamic json)
factory

Properties

amount → List<int?>
final
fee → List<int?>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited