MintInfo class

Constructors

MintInfo({required String miner, required String blockHash, required List<ValueTransferOutput> outputs, required int txnEpoch, required String txnHash, required int txnTime, required String type})
MintInfo.fromJson(Map<String, dynamic> json)
factory
MintInfo.fromRawJson(String str)
factory

Properties

blockHash → String
final
hashCode → int
The hash code for this object.
no setterinherited
miner → String
final
outputs → List<ValueTransferOutput>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txnEpoch → int
final
txnHash → String
final
txnTime → int
final
type → String
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printDebug() → void
rawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited