NetworkStats class

Constructors

NetworkStats({required int epochs, required int numActiveNodes, required int numBlocks, required int numDataRequests, required int numPendingRequests, required int numReputedNodes, required int numValueTransfers})
NetworkStats.fromJson(Map<String, dynamic> json)
factory
NetworkStats.fromRawJson(String str)
factory

Properties

epochs → int
final
hashCode → int
The hash code for this object.
no setterinherited
numActiveNodes → int
final
numBlocks → int
final
numDataRequests → int
final
numPendingRequests → int
final
numReputedNodes → int
final
numValueTransfers → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited