PrioritiesEstimate class

Constructors

PrioritiesEstimate({required PriorityEstimate stinky, required PriorityEstimate low, required PriorityEstimate medium, required PriorityEstimate high, required PriorityEstimate opulent})
PrioritiesEstimate.fromJson(Map<String, dynamic> json)
factory
PrioritiesEstimate.fromRawJson(String str)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
high → PriorityEstimate
final
low → PriorityEstimate
final
medium → PriorityEstimate
final
opulent → PriorityEstimate
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stinky → PriorityEstimate
final

Methods

jsonMap() → Map<String, PriorityEstimate>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited