PriorityEstimate class

Constructors

PriorityEstimate({required double priority, required int timeToBlock})
PriorityEstimate.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
priority → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeToBlock → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited