Rollback class

Constructors

Rollback({required int timestamp, required int epochFrom, required int epochTo, required int length})
Rollback.fromJson(Map<String, dynamic> data)
factory

Properties

epochFrom → int
final
epochTo → int
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited