StakeInfo class

Inheritance

Constructors

StakeInfo({required String block, required String? changeAddress, required int? changeValue, required bool confirmed, required int epoch, required int fee, required String hash, required List<StakeInput> inputs, required int priority, required bool reverted, required int stakeValue, required int timestamp, required String validator, required int weight, required String withdrawer})
StakeInfo.fromJson(Map<String, dynamic> data)
factory

Properties

block → String
final
blockHash → dynamic
finalinherited
changeAddress → String?
final
changeValue → int?
final
confirmed → bool
final
epoch → int
final
fee → int
final
hash → String
final
hashCode → int
The hash code for this object.
no setterinherited
inputs → List<StakeInput>
final
priority → int
final
reverted → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stakeValue → int
final
status → TxStatusLabel
finalinherited
timestamp → int
final
txnHash → String
finalinherited
txnTime → int
finalinherited
type → TransactionType
finalinherited
validator → String
final
weight → int
final
withdrawer → String
final

Methods

jsonMap() → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printDebug() → void
inherited
toRawJson() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited