TallyTxn class

Constructors

TallyTxn({required String blockHash, required int epoch, required List<String> errors, required List liars, required int numErrors, required int numLiars, required String status, required bool success, required String tally, required int time, required String txnHash})
TallyTxn.fromJson(Map<String, dynamic> json)
factory
TallyTxn.fromRawJson(String str)
factory

Properties

blockHash → String
final
epoch → int
final
errors → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
liars → List
final
numErrors → int
final
numLiars → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
success → bool
final
tally → String
final
time → int
final
txnHash → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited