Tapi class

Constructors

Tapi({required Map<String, TapiInfo> tapis})
Tapi.fromJson(List tapis)
factory
Tapi.fromRawJson(String str)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tapis → Map<String, TapiInfo>
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited