TapiInfo class

Constructors

TapiInfo({required bool activated, required bool active, required int bit, required int currentEpoch, required String description, required bool finished, required double globalAcceptanceRate, required int lastUpdated, required List<Rate> rates, required double relativeAcceptanceRate, required int startEpoch, required int startTime, required int stopEpoch, required int stopTime, required int tapiId, required String title, required List<String> urls})
TapiInfo.fromJson(Map<String, dynamic> json)
factory
TapiInfo.fromRawJson(String str)
factory

Properties

activated → bool
final
active → bool
final
bit → int
final
currentEpoch → int
final
description → String
final
finished → bool
final
globalAcceptanceRate → double
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdated → int
final
rates → List<Rate>
final
relativeAcceptanceRate → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startEpoch → int
final
startTime → int
final
stopEpoch → int
final
stopTime → int
final
tapiId → int
final
title → String
final
urls → List<String>
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited