TransactionUtxo class

Constructors

TransactionUtxo({required String address, required int value, required int timelock, required bool locked})
TransactionUtxo.fromJson(Map<String, dynamic> json)
factory

Properties

address → String
final
hashCode → int
The hash code for this object.
no setterinherited
locked → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timelock → int
final
value → int
final

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited