ValueTransferInfo class

Inheritance

Constructors

ValueTransferInfo({required int epoch, required int timestamp, required String hash, required List<String> inputAddresses, required List<String> outputAddresses, required int? value, required int fee, required int weight, required int priority, required String block, required bool confirmed, required bool reverted, required List<InputUtxo> inputUtxos, required List<InputMerged> inputsMerged, required List<int> outputValues, required List<int> timelocks, required List<TransactionUtxo> utxos, required List<TransactionUtxo> utxosMerged, required List<String> trueOutputAddresses, required List<String> changeOutputAddresses, int? trueValue, int? changeValue, required TxStatusLabel status, required List<ValueTransferOutput> outputs})
ValueTransferInfo.fromJson(Map<String, dynamic> data)
factory

Properties

block → String
final
blockHash → dynamic
finalinherited
changeOutputAddresses → List<String>
final
changeValue → int?
final
confirmed → bool
final
epoch → int
final
fee → int
final
hash → String
final
hashCode → int
The hash code for this object.
no setterinherited
inputAddresses → List<String>
final
inputsMerged → List<InputMerged>
final
inputUtxos → List<InputUtxo>
final
outputAddresses → List<String>
final
outputs → List<ValueTransferOutput>
final
outputValues → List<int>
final
priority → int
final
reverted → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TxStatusLabel
final
timelocks → List<int>
final
timestamp → int
final
trueOutputAddresses → List<String>
final
trueValue → int?
final
txnHash → String
finalinherited
txnTime → int
finalinherited
type → TransactionType
finalinherited
utxos → List<TransactionUtxo>
final
utxosMerged → List<TransactionUtxo>
final
value → int?
final
weight → int
final

Methods

containsAddress(String address) → bool
jsonMap() → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printDebug() → void
override
rawJson() → String
toRawJson() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited