NodeClient class

Constructors

NodeClient({required String address, required int port, bool keepAlive = false})

Properties

address ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → int?
no setter
keepAlive ↔ bool
getter/setter pair
messages ↔ List<String>
getter/setter pair
port ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

authorizeStake(String withdrawer) → Future<KeyedSignature>
dataRequestReport({required String transactionHash}) → Future<Map<String, dynamic>>
Data request info
formatRequest({required String method, dynamic params}) → Map<String, dynamic>
Create JSON RPC request
getBalance({required String address}) → Future<Map<String, dynamic>>
Get balance
getBlock({required String blockHash}) → Future<Block>
Get block by hash
getBlockChain({required int epoch, required int limit}) → Future
Get the list of all the known block hashes.
getConsensusConstants() → Future<ConsensusConstants>
Get consensus constants used by the node
getMempool() → Future<Map<String, dynamic>>
Get all the pending transactions
getReputation({required String address}) → Future<Map<String, dynamic>>
Get Reputation of one pkh
getReputationAll() → Future<Map<String, dynamic>>
getSuperBlock() → Future<Map<String, dynamic>>
Get the blocks that pertain to the superblock index
getTransaction(String transactionHash) → Future
Get transaction by hash
getUtxoInfo({required String address}) → Future<UtxoInfo>
Get utxos
inventory(Map<String, dynamic> inventoryItem) → Future
The inventory method is used to submit transactions.
knownPeers() → Future<List<Peer>>
Get list of known peers
nodeStats() → Future<NodeStats>
Get the node stats
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peers() → Future<List<Peer>>
Get list of consolidated peers
queryStakes(String? validator, String? withdrawer) → Future<int?>
sendDRTransaction(DRTransaction drTransaction) → Future
sendMessage(Map<String, dynamic> message) → Future<Map<String, dynamic>>
Send a request to the Node and wait for a response
sendStakeTransaction({required StakeTransaction stake}) → Future
sendUnstakeTransaction({required UnstakeTransaction unstake}) → Future<bool>
sendVTTransaction(VTTransaction vtTransaction) → Future
syncStatus() → Future<SyncStatus>
Get node status
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited