UtxoInfo class

Constructors

UtxoInfo({required int collateralMin, required List<Utxo> utxos})
UtxoInfo.fromJson(Map<String, dynamic> json)
factory
UtxoInfo.fromRawJson(String str)
factory

Properties

collateralMin ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utxos ↔ List<Utxo>
getter/setter pair

Methods

jsonMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited