RadBoolean class

Constructors

RadBoolean(bool _value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

asString() → RadString
negate() → RadBoolean
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
op(int op, [dynamic key]) → dynamic
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

False → RadBoolean
no setter
True → RadBoolean
no setter