RadFloat class

Constructors

RadFloat(double _value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
value → double
no setter

Methods

absolute() → RadFloat
asString() → RadString
ceiling() → RadInteger
floor() → RadInteger
greaterThan(RadFloat i) → RadBoolean
lessThan(RadFloat i) → RadBoolean
modulo(dynamic i) → RadInteger
multiply(num i) → RadFloat
negate(dynamic i) → RadFloat
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
op(int op, [dynamic key]) → dynamic
power(dynamic i) → RadFloat
round() → RadInteger
toString() → String
A string representation of this object.
override
truncate(int precision) → RadFloat

Operators

operator ==(Object other) → bool
The equality operator.
inherited