RadMap class

Inheritance

Constructors

RadMap(Map _value)
RadMap.fromJson(Map<String, dynamic> jsonMap)
factory

Properties

entries → Iterable<MapEntry>
The map entries of this Map.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable
The keys of this Map.
no setteroverride
length → int
The number of key/value pairs in the map.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
value → Map
no setter
values → Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry> newEntries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<RK, RV>() → Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
override
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
forEach(void action(dynamic key, dynamic value)) → void
Applies action to each key/value pair of the map.
inherited
getArray(String key) → RadArray
getBoolean(String key) → RadBoolean
getBytes(String key) → RadBytes
getFloat(String key) → RadFloat
getInteger(String key) → RadInteger
getMap(String key) → RadMap
getString(String key) → RadString
map<K2, V2>(MapEntry<K2, V2> transform(dynamic key, dynamic value)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
op(int op, [dynamic key]) → dynamic
processScript(String data, List<int> script) → dynamic
putIfAbsent(dynamic key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
override
removeWhere(bool test(dynamic key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
inherited
toString() → String
A string representation of this object.
override
update(dynamic key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(dynamic key, dynamic value)) → void
Updates all values.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
override
operator []=(dynamic key, dynamic value) → void
Associates the key with the given value.
override