RadString class

Constructors

RadString(String _value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
value → String
no setter

Methods

asBoolean() → RadBoolean
asFloat() → RadFloat
asInteger() → RadInteger
length() → RadInteger
match(String other) → RadBoolean
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
op(int op, [dynamic key]) → dynamic
parseJSONArray() → RadArray
parseJSONMap() → RadMap
toLowerCase() → RadString
toString() → String
A string representation of this object.
override
toUpperCase() → RadString

Operators

operator ==(Object other) → bool
The equality operator.
inherited