RadonArray class

Inheritance

Constructors

RadonArray(List script)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script ↔ List
getter/setter pairinherited

Methods

count() → RadonInteger
encode() → List
inherited
filter(List i) → RadonArray
getArray(int i) → RadonArray
getBoolean(int i) → RadonBoolean
getBytes(int i) → RadonBytes
getFloat(int i) → RadonFloat
getInteger(int i) → RadonInteger
getMap(int i) → RadonMap
getString(int i) → RadonString
initScript(List data) → void
inherited
map(int i) → RadonArray
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(int i) → RadonArray
sort(int i) → RadonArray
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited