RadonBytes class

Inheritance

Constructors

RadonBytes(List script)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script ↔ List
getter/setter pairinherited

Methods

asString() → RadonString
encode() → List
inherited
hash() → RadonString
Creates a combined hash code for a number of objects.
override
initScript(List data) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited