RadonFloat class

Inheritance

Constructors

RadonFloat(List script)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script ↔ List
getter/setter pairinherited

Methods

absolute() → RadonFloat
asString() → RadonString
ceiling() → RadonInteger
encode() → List
inherited
floor() → RadonInteger
greaterThan(double i) → RadonBoolean
initScript(List data) → void
inherited
lessThan(double i) → RadonBoolean
modulo(int i) → RadonInteger
multiply(num i) → RadonFloat
negate() → RadonFloat
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
power(int i) → RadonFloat
round() → RadonInteger
toString() → String
A string representation of this object.
inherited
truncate(int i) → RadonFloat

Operators

operator ==(Object other) → bool
The equality operator.
inherited