RadonMap class

Inheritance

Constructors

RadonMap([List script = emptyList])

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script ↔ List
getter/setter pairinherited

Methods

encode() → List
inherited
getArray(String key) → RadonArray
getBoolean(String key) → RadonBoolean
getBytes(String key) → RadonBytes
getFloat(String key) → RadonFloat
getInteger(String key) → RadonInteger
getMap(String key) → RadonMap
getString(String key) → RadonString
initScript(List data) → void
inherited
keys() → RadonArray
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valuesAsArray() → RadonArray

Operators

operator ==(Object other) → bool
The equality operator.
inherited