RadonString class

Inheritance

Constructors

RadonString([List? script])

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script ↔ List
getter/setter pairinherited

Methods

asBoolean() → RadonBoolean
asFloat() → RadonFloat
asInteger() → RadonInteger
encode() → List
inherited
initScript(List data) → void
inherited
length() → RadonInteger
match(Map<String, dynamic> key, bool state) → RadonBoolean
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseJSONArray() → RadonArray
parseJSONMap() → RadonMap
toLowerCase() → RadonString
toString() → String
A string representation of this object.
inherited
toUpperCase() → RadonString

Operators

operator ==(Object other) → bool
The equality operator.
inherited