Stage class

Constructors

Stage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestCache ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptCache ↔ Map<String, dynamic>
getter/setter pair

Methods

aggregateStage(List<RetrieveReport> reports, RADAggregate aggregate) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processScript(String data, List<int> script) → dynamic
retrievalStage(RADRequest radRequest, List<RetrieveReport> reports) → Future<void>
runRadRequest(RADRequest radRequest, {bool printDebug = false}) → Future<Map<String, dynamic>>
tallyStage() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited