Stats<T extends num> class

Constructors

Stats(int count, T max, T min, num sum, num mean, num median, dynamic mode, List<num> data)
Stats.fromData(Iterable<T> source)
factory

Properties

count ↔ int
getter/setter pair
data ↔ List<num>
getter/setter pair
deviationAbsolute → num
no setter
deviationRelative → num
no setter
deviationStandard → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
max ↔ T
getter/setter pair
mean ↔ num
getter/setter pair
median ↔ num
getter/setter pair
min ↔ T
getter/setter pair
mode ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardError → num
no setter
sum ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printDebug() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited