Witnet class

Constructors

Witnet(String url)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Aggregator() → RADAggregate
GraphQLSource(String url, String body, Map<String, String> headers, dynamic script, [RADType kind = RADType.HttpPost]) → RADRetrieve
RandomSource() → RADRetrieve
Request() → DataRequest
Script(RadType type) → List
Source(String url, dynamic script, [RADType kind = RADType.HttpGet]) → RADRetrieve
Tally() → RADTally