ConsensusConstants class

Inheritance
  • Object
  • GeneratedMessage
  • ConsensusConstants

Constructors

ConsensusConstants({Int64? checkpointZeroTimestamp, int? checkpointsPeriod, Hash? bootstrapHash, Hash? genesisHash, int? maxVtWeight, int? maxDrWeight, int? activityPeriod, int? reputationExpireAlphaDiff, int? reputationIssuance, int? reputationIssuanceStop, double? reputationPenalizationFactor, int? miningBackupFactor, int? miningReplicationFactor, Int64? collateralMinimum, int? collateralAge, int? superblockPeriod, int? extraRounds, int? minimumDifficulty, int? epochsWithMinimumDifficulty, Iterable<String>? bootstrappingCommittee, int? superblockSigningCommitteeSize, int? superblockCommitteeDecreasingPeriod, int? superblockCommitteeDecreasingStep, Int64? initialBlockReward, int? halvingPeriod})
factory
ConsensusConstants.fromBuffer(List<int> i, [ExtensionRegistry r = ExtensionRegistry.EMPTY])
factory
ConsensusConstants.fromJson(Map<String, dynamic> data)
factory

Properties

activityPeriod ↔ int
getter/setter pair
bootstrapHash ↔ Hash
getter/setter pair
bootstrappingCommittee → List<String>
no setter
checkpointsPeriod ↔ int
getter/setter pair
checkpointZeroTimestamp ↔ Int64
getter/setter pair
collateralAge ↔ int
getter/setter pair
collateralMinimum ↔ Int64
getter/setter pair
epochsWithMinimumDifficulty ↔ int
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
extraRounds ↔ int
getter/setter pair
genesisHash ↔ Hash
getter/setter pair
halvingPeriod ↔ int
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
initialBlockReward ↔ Int64
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
maxDrWeight ↔ int
getter/setter pair
maxVtWeight ↔ int
getter/setter pair
minimumDifficulty ↔ int
getter/setter pair
miningBackupFactor ↔ int
getter/setter pair
miningReplicationFactor ↔ int
getter/setter pair
reputationExpireAlphaDiff ↔ int
getter/setter pair
reputationIssuance ↔ int
getter/setter pair
reputationIssuanceStop ↔ int
getter/setter pair
reputationPenalizationFactor ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
superblockCommitteeDecreasingPeriod ↔ int
getter/setter pair
superblockCommitteeDecreasingStep ↔ int
getter/setter pair
superblockPeriod ↔ int
getter/setter pair
superblockSigningCommitteeSize ↔ int
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearActivityPeriod() → void
clearBootstrapHash() → void
clearCheckpointsPeriod() → void
clearCheckpointZeroTimestamp() → void
clearCollateralAge() → void
clearCollateralMinimum() → void
clearEpochsWithMinimumDifficulty() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearExtraRounds() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGenesisHash() → void
clearHalvingPeriod() → void
clearInitialBlockReward() → void
clearMaxDrWeight() → void
clearMaxVtWeight() → void
clearMinimumDifficulty() → void
clearMiningBackupFactor() → void
clearMiningReplicationFactor() → void
clearReputationExpireAlphaDiff() → void
clearReputationIssuance() → void
clearReputationIssuanceStop() → void
clearReputationPenalizationFactor() → void
clearSuperblockCommitteeDecreasingPeriod() → void
clearSuperblockCommitteeDecreasingStep() → void
clearSuperblockPeriod() → void
clearSuperblockSigningCommitteeSize() → void
clone() → ConsensusConstants
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(GeneratedMessage)) → GeneratedMessage
Apply updates to a copy of this message.
inherited
createEmptyInstance() → ConsensusConstants
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureBootstrapHash() → Hash
ensureGenesisHash() → Hash
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasActivityPeriod() → bool
hasBootstrapHash() → bool
hasCheckpointsPeriod() → bool
hasCheckpointZeroTimestamp() → bool
hasCollateralAge() → bool
hasCollateralMinimum() → bool
hasEpochsWithMinimumDifficulty() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasExtraRounds() → bool
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasGenesisHash() → bool
hasHalvingPeriod() → bool
hasInitialBlockReward() → bool
hasMaxDrWeight() → bool
hasMaxVtWeight() → bool
hasMinimumDifficulty() → bool
hasMiningBackupFactor() → bool
hasMiningReplicationFactor() → bool
hasReputationExpireAlphaDiff() → bool
hasReputationIssuance() → bool
hasReputationIssuanceStop() → bool
hasReputationPenalizationFactor() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSuperblockCommitteeDecreasingPeriod() → bool
hasSuperblockCommitteeDecreasingStep() → bool
hasSuperblockPeriod() → bool
hasSuperblockSigningCommitteeSize() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
jsonMap() → Map<String, dynamic>
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited