utils library

Classes

Bech32
Bech32 is a dead simple wrapper around a Human Readable Part (HRP) and a bunch of bytes.
Bech32Decoder
DotEnvUtil

Mixins

Bech32Validations
Generic validations for Bech32 standard.

Constants

bech32 → const Bech32Codec
An instance of the default implementation of the Bech32Codec.
utf8 → const Utf8Codec

Functions

bigIntToBytes(BigInt bigInt) → Uint8List
bigIntToHex(BigInt i) → String
binaryToBigInt(String binary) → BigInt
binaryToHex(String binary) → String
bytesToBigInt(Uint8List bytes) → BigInt
bytesToBinary(Uint8List bytes) → String
bytesToHex(Uint8List bytes) → String
bytesToString(Uint8List bytes) → String
concatBytes(List<Uint8List> byteLists) → Uint8List
convertBits({required List<int> data, required int from, required int to, required bool pad}) → List<int>
hexToBigInt(String hex) → BigInt
hexToBytes(String hex) → Uint8List
leftJustify(Uint8List bytes, int size, int value) → Uint8List
nanoWitToWit(int value) → double
rightJustify(Uint8List bytes, int size, int value) → Uint8List
stringToBytes(String string) → Uint8List
witToNanoWit(double value) → int